@@ -69,6 +69,10 @@ select_target_disk() {
 		echo "    Label = $(/lib/udev/vol_id -l $TARGET_DISK$a)"
 		echo "    UUID  = $(/lib/udev/vol_id -u $TARGET_DISK$a)"
 		echo ""
+	elif [ -f /sbin/blkid ] ; then
+		echo "Device information for $TARGET_DISK$a"
+		blkid -o list "$TARGET_DISK$a"
+		echo ""
 	fi
 	
 	
