@@ -134,11 +134,10 @@ var onLogInFunctions = {
 					'h263p': 'H.263p',
 					'h264' : 'H.264'
 				};
-
-				/* add video codecs for 1.6 platforms */
-			} else { /* if system is either 1.4 or unknown */
-				sessionData.PLATFORM.isAST_1_4 = true ;
-				sessionData.PLATFORM.isAST_1_6 = false ;
+			} else {
+				sessionData.PLATFORM.isAST_1_4 = false ;
+				sessionData.PLATFORM.isAST_1_6 = true ;
+				sessionData.PLATFORM.isAST_1_6_1 = true ;
 			}
 		}
 	},
@@ -552,7 +551,7 @@ var onLogInFunctions = {
 		}
 
 		//if( sessionData.PLATFORM.isAA50  ){
-			DOM_mainscreen.src = 'home.html?status=1';
+			DOM_mainscreen.src = 'home.html?status=0';
 		//}
 
 		if( sessionData.PLATFORM.isAA50 && sessionData.PLATFORM.AA50_SKU.contains('800') ){
@@ -1118,7 +1117,7 @@ var after_localajaxinit = function(){
 		 * doing time intervals for includes :-/
 		 * */
 		if (!sessionData.PLATFORM.isAST_1_6) {
-			top.session.delimiter = '|';
+			top.session.delimiter = ',';
 		}
 	};
 
